@@ -6,10 +6,12 @@
 #include <linux/vt.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <errno.h>
 #include <fcntl.h>
 #include "getfd.h"
 #include "nls.h"
 #include "version.h"
+#include "kbd_error.h"
 
 int
 main(int argc, char *argv[]) {
@@ -22,21 +24,23 @@ main(int argc, char *argv[]) {
     textdomain(PACKAGE_NAME);
 
     if (argc == 2 && !strcmp(argv[1], "-V"))
-	print_version_and_exit();
+        print_version_and_exit();
 
     if (argc != 2) {
-	fprintf(stderr, _("usage: chvt N\n"));
-	exit(1);
+        fprintf(stderr, _("usage: chvt N\n"));
+        return EXIT_FAILURE;
     }
+
     fd = getfd(NULL);
     num = atoi(argv[1]);
+
     if (ioctl(fd,VT_ACTIVATE,num)) {
-	perror("chvt: VT_ACTIVATE");
-	exit(1);
+        kbd_error(EXIT_FAILURE, errno, "ioctl VT_ACTIVATE");
     }
+
     if (ioctl(fd,VT_WAITACTIVE,num)) {
-	perror("VT_WAITACTIVE");
-	exit(1);
+        kbd_error(EXIT_FAILURE, errno, "ioctl VT_WAITACTIVE");
     }
-    exit(0);
+
+    return EXIT_SUCCESS;
 }
