@@ -17,6 +17,7 @@
 # else
 #  define N_(String) (String)
 # endif
+# define P_(singular, plural, number) ngettext(singular, plural, number)
 #else
 # undef bindtextdomain
 # define bindtextdomain(Domain, Directory) /* empty */
@@ -24,6 +25,5 @@
 # define textdomain(Domain) /* empty */
 # define _(Text) (Text)
 # define N_(Text) (Text)
+# define P_(singular, plural, number) (number == 1 ? singular : plural)
 #endif
-
-
